﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Shapes;

namespace VectorGrafik
{
    public class DesignerItem : ContentControl
    {
       
        public int NumberOfPoints { get; set; }
        public DesignerCanvas designerCanvas;
        public bool IsSelected
        {
            get { return (bool)GetValue(IsSelectedProperty); }
            set { SetValue(IsSelectedProperty, value); }
        }
        public static readonly DependencyProperty IsSelectedProperty =
          DependencyProperty.Register("IsSelected", typeof(bool),
                                      typeof(DesignerItem),
                                      new FrameworkPropertyMetadata(false));

        public static readonly DependencyProperty MoveThumbTemplateProperty =
            DependencyProperty.RegisterAttached("MoveThumbTemplate", typeof(ControlTemplate), typeof(DesignerItem));

        public static ControlTemplate GetMoveThumbTemplate(UIElement element)
        {
            return (ControlTemplate)element.GetValue(MoveThumbTemplateProperty);
        }

        public static void SetMoveThumbTemplate(UIElement element, ControlTemplate value)
        {
            element.SetValue(MoveThumbTemplateProperty, value);
        }

        static DesignerItem()
        {
          //  FrameworkElement.DefaultStyleKeyProperty.OverrideMetadata(typeof(DesignerItem), new FrameworkPropertyMetadata(typeof(DesignerItem)));
          
        }

        public DesignerItem(DesignerCanvas DesignerCanvas)
        {
            this.Loaded += new RoutedEventHandler(this.DesignerItem_Loaded);
            designerCanvas = DesignerCanvas;
        }

        void menuItemDelete_Click(object sender, RoutedEventArgs e)
        {
            designerCanvas.Delete(this);
        }

        void menuItemBringBackward_Click(object sender, RoutedEventArgs e)
        {
            designerCanvas.SendBackward(this);
        }
 

        void menuItemBringForward_Click(object sender, RoutedEventArgs e)
        {
            designerCanvas.BringForward(this);
        }

        void menuItemBringToBack_Click(object sender, RoutedEventArgs e)
        {
            designerCanvas.SendToBack(this);
        }

        void menuItemBringToFront_Click(object sender, RoutedEventArgs e)
        {
            designerCanvas.BringToFront(this);
        }



        protected override void OnPreviewMouseDown(MouseButtonEventArgs e)
        {
            base.OnPreviewMouseDown(e);
            DesignerCanvas designer = VisualTreeHelper.GetParent(this) as DesignerCanvas;
            if (designer != null)
            {
                if (e.LeftButton == MouseButtonState.Pressed)
                {
                    if ((Keyboard.Modifiers & (ModifierKeys.Shift | ModifierKeys.Control)) != ModifierKeys.None)
                    {
                        this.IsSelected = !this.IsSelected;
                    }
                    else
                    {
                        if (!this.IsSelected)
                        {
                            designer.DeselectAll();
                            this.IsSelected = true;
                        }
                    }
                }
            }
           
        }

        private void DesignerItem_Loaded(object sender, RoutedEventArgs e)
        {
            if (this.Template != null)
            {
                ContentPresenter contentPresenter =
                    this.Template.FindName("PART_ContentPresenter", this) as ContentPresenter;

                MoveThumb thumb =
                    this.Template.FindName("PART_MoveThumb", this) as MoveThumb;

                if (contentPresenter != null && thumb != null)
                {
                    UIElement contentVisual =
                        VisualTreeHelper.GetChild(contentPresenter, 0) as UIElement;

                    if (contentVisual != null)
                    {
                        ControlTemplate template =
                            DesignerItem.GetMoveThumbTemplate(contentVisual) as ControlTemplate;

                        if (template != null)
                        {
                            thumb.Template = template;
                        }
                    }
                }
            }
        }

        
    }
}
