﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Shapes;
using System.Windows.Media;
using System.Windows.Documents;
using System.Windows.Controls.Primitives;


namespace VectorGrafik
{
    internal enum GraficState { grfNormal, grfDraw};
    internal enum ObjectTyp { MyLine, MyEllipse, MyRectangle, MyTriangle };


    internal class Graphic2D
    {
        internal void Save(string FileName)
        {
            canvas.Save_Executed(FileName);
        }
        internal string SaveAs()
        {
            return canvas.SaveAs_Executed();
        }
        internal string Open()
        {
            return canvas.Open_Executed();
        }
        private DesignerCanvas canvas;
        internal GraficState State { get; set; }
        internal Graphic2D(DesignerCanvas Canvas)
        {
            canvas = Canvas;
        }
        internal void CreateNewRectangle(Point TopLeft, Point ButtonRight)
        {
            DesignerItem c = new DesignerItem(canvas);
            c.NumberOfPoints = 2;
            c.Width = Math.Abs(ButtonRight.X - TopLeft.X);
            c.Height = Math.Abs(ButtonRight.Y - TopLeft.Y);
            c.IsHitTestVisible = true;
            Grid grid = new Grid();
            Rectangle r = new Rectangle();
            r.Stroke = Brushes.Black;
            r.IsHitTestVisible = false;
            r.StrokeThickness = 1;
            grid.Children.Add(r);
            c.Content = grid;
            double topLeftX = Math.Min(TopLeft.X, ButtonRight.X);
            double topLeftY = Math.Min(TopLeft.Y, ButtonRight.Y);
            Canvas.SetLeft(c, topLeftX);
            Canvas.SetTop(c, topLeftY);
            canvas.Children.Add(c);
        }
        internal void CreateNewTriangle(Point P1, Point P2, Point P3)
        {
            DesignerItem c = new DesignerItem(canvas);
            c.NumberOfPoints = 3;
            c.Width = Math.Max(Math.Max(Math.Abs(P1.X - P2.X), Math.Abs(P1.X - P3.X)), Math.Abs(P2.X - P3.X));
            c.Height = Math.Max(Math.Max(Math.Abs(P1.Y - P2.Y), Math.Abs(P1.Y - P3.Y)), Math.Abs(P2.Y - P3.Y));
            c.IsHitTestVisible = true;
            Grid grid = new Grid();
            Polygon pl = new Polygon();
            pl.Points.Add(P1);
            pl.Points.Add(P2);
            pl.Points.Add(P3);
            pl.Stretch = Stretch.Fill;
            pl.StrokeThickness = 1;
            pl.Stroke = Brushes.Black;
            pl.IsHitTestVisible = false;
            grid.Children.Add(pl);
            c.Content = grid;
            double topLeftX = Math.Min(Math.Min(P1.X, P2.X),P3.X);
            double topLeftY = Math.Min(Math.Min(P1.Y, P2.Y),P3.Y);
            Canvas.SetLeft(c, topLeftX);
            Canvas.SetTop(c, topLeftY);
            canvas.Children.Add(c);

        }
        internal void CreateNewEllipse(Point TopLeft, Point ButtonRight)
        {
            DesignerItem c = new DesignerItem(canvas);
            c.NumberOfPoints = 2;
            c.Width = Math.Abs(ButtonRight.X - TopLeft.X);
            c.Height = Math.Abs(ButtonRight.Y - TopLeft.Y);
            Grid grid = new Grid();
            Ellipse r = new Ellipse();
            r.Stroke = Brushes.Black;
            r.IsHitTestVisible = false;
            c.IsHitTestVisible = true;
            r.StrokeThickness = 1;
            grid.Children.Add(r);
            c.Content = grid;
            double topLeftX = Math.Min(TopLeft.X, ButtonRight.X);
            double topLeftY = Math.Min(TopLeft.Y, ButtonRight.Y);
            Canvas.SetLeft(c, topLeftX);
            Canvas.SetTop(c, topLeftY);
            canvas.Children.Add(c);
        }
        internal void CreateNewLine(Point TopLeft, Point ButtonRight)
        {
           
                DesignerItem c = new DesignerItem(canvas);
                c.NumberOfPoints = 2;
                c.Width = Math.Abs(ButtonRight.X - TopLeft.X);
                c.Height = Math.Abs(ButtonRight.Y - TopLeft.Y);
                Grid grid = new Grid();
                Line l = new Line();
                if (TopLeft.X < ButtonRight.X)
                {
                    l.X1 = 0;
                    l.X2 = c.Width;
                }
                else
                {
                    l.X1 = c.Width;
                    l.X2 = 0;
                }

                if (TopLeft.Y < ButtonRight.Y)
                {

                    l.Y1 = 0;
                    l.Y2 = c.Height;
                }
                else
                {
                    l.Y1 = c.Height;
                    l.Y2 = 0;
                }

                l.Stretch = Stretch.Fill;
                l.StrokeThickness = 1;
                l.Stroke = Brushes.Black;
                grid.Children.Add(l);
                c.Content = grid;
                double topLeftX = Math.Min(TopLeft.X, ButtonRight.X);
                double topLeftY = Math.Min(TopLeft.Y, ButtonRight.Y);
                Canvas.SetLeft(c, topLeftX);
                Canvas.SetTop(c, topLeftY);
                canvas.Children.Add(c);
        }
        internal void DeleteLastElement()
        {
             canvas.Children.RemoveAt(canvas.Children.Count - 1);
        }
        internal void Clear()
        {
            canvas.Children.Clear();
        }
    }
}
